Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Managed Streaming for Apache Kafka.

Actions, resources, and condition keys for Amazon Managed Streaming for Apache Kafka - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Managed Streaming for Apache Kafka

Amazon Managed Streaming for Apache Kafka (service prefix: `kafka` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Managed Streaming for Apache Kafka
- Resource types defined by Amazon Managed Streaming for Apache Kafka
- Condition keys for Amazon Managed Streaming for Apache Kafka

## Actions defined by Amazon Managed Streaming for Apache Kafka

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchAssociateScramSecret | Grants permission to associate one or more Scram Secrets with an Amazon MSK cluster | Write | cluster* |  | kms:CreateGrant kms:RetireGrant
BatchDisassociateScramSecret | Grants permission to disassociate one or more Scram Secrets from an Amazon MSK cluster | Write | cluster* |  | kms:RetireGrant
CreateCluster | Grants permission to create an MSK cluster | Write | cluster* |  | ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcs iam:AttachRolePolicy iam:CreateServiceLinkedRole iam:PutRolePolicy kms:CreateGrant kms:DescribeKey
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateClusterV2 | Grants permission to create an MSK cluster | Write | cluster* |  | ec2:CreateTags ec2:CreateVpcEndpoint ec2:DeleteVpcEndpoints ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcAttribute ec2:DescribeVpcEndpoints ec2:DescribeVpcs iam:AttachRolePolicy iam:CreateServiceLinkedRole iam:PutRolePolicy kms:CreateGrant kms:DescribeKey
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateConfiguration | Grants permission to create an MSK configuration | Write | configuration* |  |
CreateVpcConnection | Grants permission to create a MSK VPC connection | Write | cluster* |  | ec2:CreateTags ec2:CreateVpcEndpoint ec2:DescribeSecurityGroups ec2:DescribeSubnets ec2:DescribeVpcAttribute ec2:DescribeVpcEndpoints ec2:DescribeVpcs iam:AttachRolePolicy iam:CreateServiceLinkedRole iam:PutRolePolicy
vpc-connection* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteCluster | Grants permission to delete an MSK cluster | Write | cluster* |  | ec2:DeleteVpcEndpoints ec2:DescribeVpcAttribute ec2:DescribeVpcEndpoints
DeleteClusterPolicy | Grants permission to delete a cluster resource-based policy | Write | cluster* |  |
DeleteConfiguration | Grants permission to delete the specified MSK configuration | Write | configuration* |  |
DeleteVpcConnection | Grants permission to delete a MSK VPC connection | Write | vpc-connection* |  | ec2:DeleteVpcEndpoints ec2:DescribeVpcEndpoints
DescribeCluster | Grants permission to describe an MSK cluster | Read | cluster* |  |
DescribeClusterOperation | Grants permission to describe the cluster operation that is specified by the given ARN | Read |  |  |
DescribeClusterOperationV2 | Grants permission to describe the cluster operation that is specified by the given ARN | Read |  |  |
DescribeClusterV2 | Grants permission to describe an MSK cluster | Read | cluster* |  |
DescribeConfiguration | Grants permission to describe an MSK configuration | Read | configuration* |  |
DescribeConfigurationRevision | Grants permission to describe an MSK configuration revision | Read | configuration* |  |
DescribeVpcConnection | Grants permission to describe a MSK VPC connection | Read | vpc-connection* |  |
GetBootstrapBrokers | Grants permission to get connection details for the brokers in an MSK cluster | Read |  |  |
GetClusterPolicy | Grants permission to describe a cluster resource-based policy | Read | cluster* |  |
GetCompatibleKafkaVersions | Grants permission to get a list of the Apache Kafka versions to which you can update an MSK cluster | List |  |  |
ListClientVpcConnections | Grants permission to list all MSK VPC connections created for a cluster | List | cluster* |  |
ListClusterOperations | Grants permission to return a list of all the operations that have been performed on the specified MSK cluster | List | cluster* |  |
ListClusterOperationsV2 | Grants permission to return a list of all the operations that have been performed on the specified MSK cluster | List | cluster* |  |
ListClusters | Grants permission to list all MSK clusters in this account | List |  |  |
ListClustersV2 | Grants permission to list all MSK clusters in this account | List |  |  |
ListConfigurationRevisions | Grants permission to list all revisions for an MSK configuration in this account | List | configuration* |  |
ListConfigurations | Grants permission to list all MSK configurations in this account | List |  |  |
ListKafkaVersions | Grants permission to list all Apache Kafka versions supported by Amazon MSK | List |  |  |
ListNodes | Grants permission to list brokers in an MSK cluster | List | cluster* |  |
ListScramSecrets | Grants permission to list the Scram Secrets associated with an Amazon MSK cluster | List | cluster* |  |
ListTagsForResource | Grants permission to list tags of an MSK resource | Read | cluster* |  |
ListVpcConnections | Grants permission to list all MSK VPC connections that this account uses | List |  |  |
PutClusterPolicy | Grants permission to create or update the resource-based policy for a cluster | Write | cluster* |  |
RebootBroker | Grants permission to reboot broker | Write | cluster* |  |
RejectClientVpcConnection | Grants permission to reject a MSK VPC connection | Write | cluster* |  |
vpc-connection* |  |
TagResource | Grants permission to tag an MSK resource | Tagging | cluster |  |
vpc-connection |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove tags from an MSK resource | Tagging | cluster |  |
vpc-connection |  |
| aws:TagKeys |
UpdateBrokerCount | Grants permission to update the number of brokers of the MSK cluster | Write | cluster* |  |
UpdateBrokerStorage | Grants permission to update the storage size of the brokers of the MSK cluster | Write | cluster* |  |
UpdateBrokerType | Grants permission to update the broker type of an Amazon MSK cluster | Write | cluster* |  |
UpdateClusterConfiguration | Grants permission to update the configuration of the MSK cluster | Write | cluster* |  |
configuration* |  |
UpdateClusterKafkaVersion | Grants permission to update the MSK cluster to the specified Apache Kafka version | Write | cluster* |  |
UpdateConfiguration | Grants permission to create a new revision of the MSK configuration | Write | configuration* |  |
UpdateConnectivity | Grants permission to update the connectivity settings for the MSK cluster | Write | cluster* |  | ec2:DescribeRouteTables ec2:DescribeSubnets
| kafka:publicAccessEnabled |
UpdateMonitoring | Grants permission to update the monitoring settings for the MSK cluster | Write | cluster* |  |
UpdateSecurity | Grants permission to update the security settings for the MSK cluster | Write | cluster* |  | kms:RetireGrant
UpdateStorage | Grants permission to update the EBS storage (size or provisioned throughput) associated with MSK brokers or set cluster storage mode to TIERED | Write | cluster* |  |

## Resource types defined by Amazon Managed Streaming for Apache Kafka

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
cluster | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:cluster/$ { ClusterName}/$ { Uuid}` | aws:ResourceTag/${TagKey}
configuration | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:configuration/$ { ConfigurationName}/$ { Uuid}` |
vpc-connection | `arn:$ { Partition}:kafka:$ { Region}:$ { VpcOwnerAccount}:vpc-connection/$ { ClusterOwnerAccount}/$ { ClusterName}/$ { Uuid}` | aws:ResourceTag/${TagKey}
topic | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:topic/$ { ClusterName}/$ { ClusterUuid}/$ { TopicName}` |
group | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:group/$ { ClusterName}/$ { ClusterUuid}/$ { GroupName}` |
transactional-id | `arn:$ { Partition}:kafka:$ { Region}:$ { Account}:transactional-id/$ { ClusterName}/$ { ClusterUuid}/$ { TransactionalId}` |

## Condition keys for Amazon Managed Streaming for Apache Kafka

Amazon Managed Streaming for Apache Kafka defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString
kafka:publicAccessEnabled | Filters access by the presence of public access enabled in the request | Bool

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.